Module schema

Module schema 

Schema manager: in-memory cache of table schemas.

Structs

DmlDirty
DML since the last commit, classified for cache invalidation.
SchemaManager
Manages table schemas in memory, backed by the _schema table.
SchemaSnapshot