Module types

Module types 

Structs

ColumnDef
CompactString
A CompactString is a compact string type that can be used almost anywhere a String or str can be used.
ForeignKeySchemaEntry
IndexDef
IndexKey::Column for CREATE INDEX ON t (email), IndexKey::Expr for LOWER(email).
MatviewDef
Backing table shares the matview’s name and is repopulated on REFRESH.
QueryResult
TableCheckDef
TableSchema
TriggerDef
ViewDef

Enums

Collation
DataType
ExecutionResult
GinOpsClass
IndexKey
IndexKind
InvertedKind
Value
SQL value. Temporal epochs: days/µs since 1970-01-01 UTC. Date/Timestamp reserve i{32,64}::{MAX,MIN} as ±infinity sentinels.

Constants

TABLE_FLAG_STRICT