Order-preserving key encoding and row encoding for non-PK column storage.
Enums
Functions
- decode_
column_ raw - decode_
column_ with_ offset - Like
decode_column_rawbut also returns the byte offset (usize::MAX if NULL). - decode_
columns - decode_
columns_ into - decode_
composite_ key - Decode a composite key into multiple values.
- decode_
key_ value - Decode a single key value, returning the value and the number of bytes consumed.
- decode_
pk_ integer - decode_
pk_ into - decode_
row - decode_
row_ into - encode_
composite_ key - Encode a composite key (multiple values concatenated).
- encode_
composite_ key_ into - encode_
key_ value - Encode a single value into an order-preserving byte sequence.
- encode_
row - Encode non-PK columns. Format: [col_count:u16][null_bitmap][type(u8)+len(u32)+data per col]
- encode_
row_ into - patch_
at_ offset - Patch at a known byte offset. Ok(false) if size mismatch or NULL offset.
- patch_
column_ in_ place - Patch column in-place if value size unchanged. Ok(false) = size mismatch, use
patch_row_column. - patch_
row_ column - Patch a single column in encoded row, writing result into
out. Copies others unchanged. - row_
non_ pk_ count - Returns the number of non-PK columns stored in a row value blob.