Module types

Module types 

Structs

ColumnDef
Column definition.
CompactString
A CompactString is a compact string type that can be used almost anywhere a String or str can be used.
ForeignKeySchemaEntry
Foreign key definition stored in schema.
IndexDef
Index definition stored as part of the table schema.
QueryResult
Result of a SELECT query.
TableCheckDef
Table-level CHECK constraint stored in schema.
TableSchema
Table schema stored in the _schema table.
ViewDef
View definition stored in the _views metadata table.

Enums

DataType
SQL data types.
ExecutionResult
Result of executing a SQL statement.
Value
SQL value. Temporal epochs: days/µs since 1970-01-01 UTC. Date/Timestamp reserve i{32,64}::{MAX,MIN} as ±infinity sentinels.